
####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was PackageConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

#nvpl_blas-config.cmake
#
# Package COMPONENT's defined:
# Integer types:
#  * lp64 - 32-bit Integer interface
#  * ilp64 - 64-bit Integer interface
# Threading  types:
#  * seq - Sequential interface
#  * omp - OpenMP threading interface
#
# Imported interface targets provided:
#  * nvpl::blas_<lp>_<thr> - shared library targets
#  * nvpl::blas_<lp>_<thr>_static - static library targets
#
# Output variables set:
#  * nvpl_blas_INT_TYPES - List of available integer types for <lp> in targets
#  * nvpl_blas_THREADING_TYPES - List of available threading types for <thr> in targets
#  * nvpl_blas_VERSION - Version of installed package
#  * nvpl_blas_LOCATION - Location this library was found at in local system

set(nvpl_blas_VERSION 0.1.0)
# build: 411

set(nvpl_blas_INT_TYPES "lp64;ilp64")
set(nvpl_blas_THREADING_TYPES "seq;omp")

## Targets
include("${CMAKE_CURRENT_LIST_DIR}/nvpl_blas-targets.cmake")

# Find component libraries
foreach(_lp IN LISTS nvpl_blas_INT_TYPES)
    foreach(_thr IN LISTS nvpl_blas_THREADING_TYPES)
        if(_thr STREQUAL "omp")
            set(_tgt nvpl_blas_${_lp}_g${_thr})
        else()
            set(_tgt nvpl_blas_${_lp}_${_thr})
        endif()

        #Allow Alias to targets
        set_target_properties(${_tgt} PROPERTIES IMPORTED_GLOBAL 1)
        if(TARGET ${_tgt}_static)
            set_target_properties(${_tgt}_static PROPERTIES IMPORTED_GLOBAL 1)
        endif()

        # Add namespaced target aliases if not already created
        if(NOT TARGET nvpl::blas_${_lp}_${_thr})
            add_library(nvpl::blas_${_lp}_${_thr} ALIAS ${_tgt})
            if(TARGET ${_tgt}_static)
                add_library(nvpl::blas_${_lp}_${_thr}_static ALIAS ${_tgt}_static)
            endif()
        endif()
        if(NOT nvpl_blas_LOCATION)
            get_target_property(nvpl_blas_LOCATION ${_tgt} LOCATION)
            get_filename_component(nvpl_blas_LOCATION ${nvpl_blas_LOCATION} DIRECTORY)
            get_filename_component(nvpl_blas_LOCATION ${nvpl_blas_LOCATION}/.. REALPATH)
        endif()
    endforeach()
endforeach()

## PackageConfig COMPONENTS
# Find installed components
set(_components)
foreach(_lp IN ITEMS lp64;ilp64)
    if(${_lp} IN_LIST nvpl_blas_INT_TYPES)
        set(nvpl_blas_${_lp}_FOUND 1)
        list(APPEND _components ${_lp})
    endif()
endforeach()
foreach(_thr IN ITEMS seq;omp)
    if(${_thr} IN_LIST nvpl_blas_THREADING_TYPES)
        set(nvpl_blas_${_thr}_FOUND 1)
        list(APPEND _components ${_thr})
    endif()
endforeach()

# Cleanup temporary variables and check if components satisfied
unset(_lp)
unset(_thr)
unset(_tgt)
check_required_components(nvpl_blas)

## Report status
message(STATUS
"Found nvpl_blas: (Location:${nvpl_blas_LOCATION}
                   Version:${nvpl_blas_VERSION}
                   ComponentsFound:[${_components}])")
unset(_components)
